==> analysis-182.4892.12-sources.jar: com/intellij/codeInspection/ex/InspectionElementsMerger.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInspection.ex;

import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.openapi.extensions.Extensions;
import com.intellij.util.ArrayUtilRt;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.HashMap;
import java.util.Map;


/**
 * Merges multiple inspections settings {@link #getSourceToolNames()} into another one {@link #getMergedToolName()}
 *
 * {@see com.intellij.codeInspection.ex.InspectionElementsMergerBase} to provide more fine control over xml
 */
public abstract class InspectionElementsMerger {
  public static final ExtensionPointName<InspectionElementsMerger> EP_NAME = ExtensionPointName.create("com.intellij.inspectionElementsMerger");
  private static Map<String, InspectionElementsMerger> ourMergers;

  @Nullable
  public static synchronized InspectionElementsMerger getMerger(String shortName) {
    if (ourMergers == null) {
      ourMergers = new HashMap<>();
      for (InspectionElementsMerger merger : Extensions.getExtensions(EP_NAME)) {
        ourMergers.put(merger.getMergedToolName(), merger);
      }
    }
    return ourMergers.get(shortName);
  }

  /**
   * @return shortName of the new merged inspection.
   */
  @NotNull
  public abstract String getMergedToolName();

  /**
   * @return the shortNames of the inspections whose settings needs to be merged.
   */
  @NotNull
  public abstract String[] getSourceToolNames();

  /**
   * The ids to check for suppression.
   * If this returns an empty string array, the result of getSourceToolNames() is used instead.
   * @return the suppressIds of the merged inspections.
   */
  @NotNull
  public String[] getSuppressIds() {
    return ArrayUtilRt.EMPTY_STRING_ARRAY;
  }
}

==> analysis-183.3283.2-sources.jar: com/intellij/codeInspection/ex/InspectionElementsMerger.java <==
// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.codeInspection.ex;

import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.util.ArrayUtilRt;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.HashMap;
import java.util.Map;


/**
 * Merges multiple inspections settings {@link #getSourceToolNames()} into another one {@link #getMergedToolName()}
 *
 * {@see com.intellij.codeInspection.ex.InspectionElementsMergerBase} to provide more fine control over xml
 */
public abstract class InspectionElementsMerger {
  public static final ExtensionPointName<InspectionElementsMerger> EP_NAME = ExtensionPointName.create("com.intellij.inspectionElementsMerger");
  private static Map<String, InspectionElementsMerger> ourMergers;

  @Nullable
  public static synchronized InspectionElementsMerger getMerger(String shortName) {
    if (ourMergers == null) {
      ourMergers = new HashMap<>();
      for (InspectionElementsMerger merger : EP_NAME.getExtensionList()) {
        ourMergers.put(merger.getMergedToolName(), merger);
      }
    }
    return ourMergers.get(shortName);
  }

  /**
   * @return shortName of the new merged inspection.
   */
  @NotNull
  public abstract String getMergedToolName();

  /**
   * @return the shortNames of the inspections whose settings needs to be merged.
   */
  @NotNull
  public abstract String[] getSourceToolNames();

  /**
   * The ids to check for suppression.
   * If this returns an empty string array, the result of getSourceToolNames() is used instead.
   * @return the suppressIds of the merged inspections.
   */
  @NotNull
  public String[] getSuppressIds() {
    return ArrayUtilRt.EMPTY_STRING_ARRAY;
  }
}
